@@ -1,30 +1,30 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: 1_iso_8859_character_code_model.c,v $ $Revision: 1.2 $ $Date: 2009-01-31 16:06:30 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
-#ifndef 1_ISO_8859_CHARACTER_CODE_MODEL_SOURCE
-#define 1_ISO_8859_CHARACTER_CODE_MODEL_SOURCE
+#ifndef 1_ISO_8859_CHARACTER_CODE_MODEL_CONSTANT_SOURCE
+#define 1_ISO_8859_CHARACTER_CODE_MODEL_CONSTANT_SOURCE
 
 #include <stddef.h>
 
@@ -40,5 +40,5 @@
 //?? TODO: Add iso-8859-1 character codes here!
 //?? Add further files for other character codes in this directory!
 
-/* 1_ISO_8859_CHARACTER_CODE_MODEL_SOURCE */
+/* 1_ISO_8859_CHARACTER_CODE_MODEL_CONSTANT_SOURCE */
 #endif
