@@ -1,30 +1,30 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: unicode_character_code_model.c,v $ $Revision: 1.2 $ $Date: 2009-01-31 16:06:30 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
-#ifndef UNICODE_CHARACTER_CODE_MODEL_SOURCE
-#define UNICODE_CHARACTER_CODE_MODEL_SOURCE
+#ifndef UNICODE_CHARACTER_CODE_MODEL_CONSTANT_SOURCE
+#define UNICODE_CHARACTER_CODE_MODEL_CONSTANT_SOURCE
 
 #include <stddef.h>
 
@@ -977,5 +977,5 @@ static wchar_t* BOX_DRAWINGS_LIGHT_ARC_UP_AND_LEFT_UNICODE_CHARACTER_CODE_MODEL
 static wchar_t BOX_DRAWINGS_LIGHT_ARC_UP_AND_RIGHT_UNICODE_CHARACTER_CODE_MODEL_ARRAY[] = {0x2570};
 static wchar_t* BOX_DRAWINGS_LIGHT_ARC_UP_AND_RIGHT_UNICODE_CHARACTER_CODE_MODEL = BOX_DRAWINGS_LIGHT_ARC_UP_AND_RIGHT_UNICODE_CHARACTER_CODE_MODEL_ARRAY;
 
-/* UNICODE_CHARACTER_CODE_MODEL_SOURCE */
+/* UNICODE_CHARACTER_CODE_MODEL_CONSTANT_SOURCE */
 #endif
