@@ -1,63 +1,63 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: keyboard_key_cybol_name.c,v $ $Revision: 1.3 $ $Date: 2009-01-31 16:06:30 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
-#ifndef KEYBOARD_KEY_CYBOL_NAME_SOURCE
-#define KEYBOARD_KEY_CYBOL_NAME_SOURCE
+#ifndef KEYBOARD_KEY_CYBOL_NAME_CONSTANT_SOURCE
+#define KEYBOARD_KEY_CYBOL_NAME_CONSTANT_SOURCE
 
 #include <stddef.h>
-#include "../../../constant/model/memory/integer_memory_model.c"
+#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 /** The enter keyboard key cybol name. */
 static wchar_t ENTER_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'e', L'n', L't', L'e', L'r'};
 static wchar_t* ENTER_KEYBOARD_KEY_CYBOL_NAME = ENTER_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ENTER_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ENTER_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The escape keyboard key cybol name. */
 static wchar_t ESCAPE_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'e', L's', L'c', L'a', L'p', L'e'};
 static wchar_t* ESCAPE_KEYBOARD_KEY_CYBOL_NAME = ESCAPE_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ESCAPE_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_6_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ESCAPE_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The arrow up keyboard key cybol name. */
 static wchar_t ARROW_UP_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'a', L'r', L'r', L'o', L'w', L'_', L'u', L'p'};
 static wchar_t* ARROW_UP_KEYBOARD_KEY_CYBOL_NAME = ARROW_UP_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ARROW_UP_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_8_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ARROW_UP_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_8_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The arrow down keyboard key cybol name. */
 static wchar_t ARROW_DOWN_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'a', L'r', L'r', L'o', L'w', L'_', L'd', L'o', L'w', L'n'};
 static wchar_t* ARROW_DOWN_KEYBOARD_KEY_CYBOL_NAME = ARROW_DOWN_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ARROW_DOWN_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_10_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ARROW_DOWN_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The arrow left keyboard key cybol name. */
 static wchar_t ARROW_LEFT_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'a', L'r', L'r', L'o', L'w', L'_', L'l', L'e', L'f', L't'};
 static wchar_t* ARROW_LEFT_KEYBOARD_KEY_CYBOL_NAME = ARROW_LEFT_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ARROW_LEFT_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_10_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ARROW_LEFT_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The arrow right keyboard key cybol name. */
 static wchar_t ARROW_RIGHT_KEYBOARD_KEY_CYBOL_NAME_ARRAY[] = {L'a', L'r', L'r', L'o', L'w', L'_', L'r', L'i', L'g', L'h', L't'};
 static wchar_t* ARROW_RIGHT_KEYBOARD_KEY_CYBOL_NAME = ARROW_RIGHT_KEYBOARD_KEY_CYBOL_NAME_ARRAY;
-static int* ARROW_RIGHT_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_11_INTEGER_MEMORY_MODEL_ARRAY;
+static int* ARROW_RIGHT_KEYBOARD_KEY_CYBOL_NAME_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/* KEYBOARD_KEY_CYBOL_NAME_SOURCE */
+/* KEYBOARD_KEY_CYBOL_NAME_CONSTANT_SOURCE */
 #endif
