@@ -1,45 +1,46 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: xml_cybol_name.c,v $ $Revision: 1.4 $ $Date: 2009-01-31 16:06:30 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
-#ifndef XML_CYBOL_NAME_SOURCE
-#define XML_CYBOL_NAME_SOURCE
+#ifndef XML_CYBOL_NAME_CONSTANT_SOURCE
+#define XML_CYBOL_NAME_CONSTANT_SOURCE
 
 #include <stddef.h>
-#include "../../../constant/model/memory/integer_memory_model.c"
+
+#include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 /** The node xml cybol name. */
 static wchar_t NODE_XML_CYBOL_NAME_ARRAY[] = {L'n', L'o', L'd', L'e'};
 static wchar_t* NODE_XML_CYBOL_NAME = NODE_XML_CYBOL_NAME_ARRAY;
-static int* NODE_XML_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_MEMORY_MODEL_ARRAY;
+static int* NODE_XML_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
  * The node name xml cybol name.
  *
  * CAUTION! The node name is intentionally left empty.
  * The cyboi xml parser adds the xml tag name and xml attribute names
- * to a node's details, all on the same level.
+ * to a node's properties, all on the same level.
  * But because xml attributes may have arbitrary names,
  * an ambiguous situation could be caused when fixing a node's name.
  *
@@ -80,7 +81,7 @@ static int* NODE_XML_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_MEMORY_MODEL_ARRAY;
  *
  * In order to avoid an ambiguous situation of this kind,
  * the node name representing the tag name does NOT receive ANY name.
- * In other words, it is just left empty.
+ * In other words, it is just left EMPTY.
  * For the example above, this would result in the following cyboi model:
  *
  *  | compound
@@ -102,7 +103,7 @@ static int* NODE_XML_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_MEMORY_MODEL_ARRAY;
  */
 static wchar_t NODE_NAME_XML_CYBOL_NAME_ARRAY[] = {};
 static wchar_t* NODE_NAME_XML_CYBOL_NAME = NODE_NAME_XML_CYBOL_NAME_ARRAY;
-static int* NODE_NAME_XML_CYBOL_NAME_COUNT = NUMBER_0_INTEGER_MEMORY_MODEL_ARRAY;
+static int* NODE_NAME_XML_CYBOL_NAME_COUNT = NUMBER_0_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
-/* XML_CYBOL_NAME_SOURCE */
+/* XML_CYBOL_NAME_CONSTANT_SOURCE */
 #endif
