@@ -1,32 +1,32 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: orienter.c,v $ $Revision: 1.7 $ $Date: 2009-01-31 16:06:31 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef ORIENTER_SOURCE
 #define ORIENTER_SOURCE
 
-#include "../constant/model/memory/pointer_memory_model.c"
+#include "../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 
 /**
  * Orients the given stream.
@@ -36,18 +36,18 @@
  */
 void orient(void* p0, void* p1) {
 
-    if (p1 != *NULL_POINTER_MEMORY_MODEL) {
+    if (p1 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
         int* o = (int*) p1;
 
-        if (p0 != *NULL_POINTER_MEMORY_MODEL) {
+        if (p0 != *NULL_POINTER_STATE_CYBOI_MODEL) {
 
             FILE* s = (FILE*) p0;
 
             // CAUTION! DO NOT use logging functionality here!
             // The logger will not work before its options are set.
             // Do NOT show the following error message, as it would only disturb the user!
-            // log_write_terminated_message(stdout, L"Information: Orient stream.\n");
+            // log_write(stdout, L"Information: Orient stream.\n");
 
             // Set stream orientation.
             fwide(s, *o);
@@ -57,14 +57,14 @@ void orient(void* p0, void* p1) {
             // CAUTION! DO NOT use logging functionality here!
             // The logger will not work before its options are set.
             // Do NOT show the following error message, as it would only disturb the user!
-            // log_write_terminated_message(stdout, L"Error: Could not orient stream. The stream is null.\n");
+            // log_write(stdout, L"Error: Could not orient stream. The stream is null.\n");
         }
 
     } else {
 
         // CAUTION! DO NOT use logging functionality here!
         // The logger will not work before its options are set.
-        // log_write_terminated_message(stdout, L"Error: Could not orient stream. The orientation is null.\n");
+        // log_write(stdout, L"Error: Could not orient stream. The orientation is null.\n");
     }
 }
 
