@@ -1,43 +1,47 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: tester.c,v $ $Revision: 1.35 $ $Date: 2009-10-06 21:25:26 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef TESTER_SOURCE
 #define TESTER_SOURCE
 
-#include "../controller/tester/accessor_tester.c"
-#include "../controller/tester/arithmetiser_tester.c"
-#include "../controller/tester/assembler_tester.c"
-#include "../controller/tester/communicator_tester.c"
-#include "../controller/tester/comparator_tester.c"
-#include "../controller/tester/constant_tester.c"
-#include "../controller/tester/converter_tester.c"
-#include "../controller/tester/logger_tester.c"
-#include "../controller/tester/memoriser_tester.c"
-#include "../controller/tester/pointer_tester.c"
-#include "../controller/tester/preprocessor_tester.c"
-#include "../controller/tester/variable_tester.c"
+#include "../tester/accessor_tester.c"
+#include "../tester/arithmetiser_tester.c"
+#include "../tester/assembler_tester.c"
+#include "../tester/communicator_tester.c"
+#include "../tester/comparator_tester.c"
+#include "../tester/constant_tester.c"
+#include "../tester/converter_tester.c"
+#include "../tester/copier_tester.c"
+#include "../tester/empty_tester.c"
+#include "../tester/finder_tester.c"
+#include "../tester/logger_tester.c"
+#include "../tester/memoriser_tester.c"
+#include "../tester/modifier_tester.c"
+#include "../tester/pointer_tester.c"
+#include "../tester/preprocessor_tester.c"
+#include "../tester/variable_tester.c"
 
 //
 // Examples for source code testing via log messages.
@@ -61,13 +65,13 @@
     // The log file.
     int f = open(n, status);
 
-    if (f >= *NUMBER_0_INTEGER_MEMORY_MODEL) {
+    if (f >= *NUMBER_0_INTEGER_STATE_CYBOI_MODEL) {
 
         // The file owner.
-        int o = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
+        int o = *NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL;
 
         // The file group.
-        int g = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
+        int g = *NUMBER_MINUS_1_INTEGER_STATE_CYBOI_MODEL;
 
         // Set file owner.
         chown(n, o, g);
@@ -87,7 +91,7 @@
 
         // CAUTION! DO NOT use logging functionality here!
         // The logger will not work before these global variables are set.
-        log_write_terminated_message(stdout, L"Error: Could not open socket sending http_response file. A file error occured.\n");
+        log_write(stdout, L"Error: Could not open socket sending http_response file. A file error occured.\n");
     }
     // --- END TEST ---
 */
@@ -100,13 +104,13 @@
  */
 void test() {
 
-    log_terminated_message((void*) INFORMATION_LEVEL_LOG_MODEL, (void*) L"Test cyboi.");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test cyboi.");
 
-    // How to use printf to check parameter values.
+    // How to use printf to check parametre values.
     // The printf function uses stdout for output, but nothing appears on console.
     // Therefore, fprintf is used and stdout is given for output.
     // Example:
-    // int x = *NUMBER_2_INTEGER_MEMORY_MODEL;
+    // int x = *NUMBER_2_INTEGER_STATE_CYBOI_MODEL;
     // fwprintf(stdout, L"The value of x is: %d\n", x);
 
     // Globals.
@@ -125,7 +129,13 @@ void test() {
     test_communicator();
     test_comparator();
     test_converter();
+    test_copier();
+    test_finder();
     test_memoriser();
+    test_modifier();
+
+    // Empty.
+    test_empty();
 }
 
 /* TESTER_SOURCE */
