@@ -1,25 +1,25 @@
 /*
- * Copyright (C) 1999-2011. Christian Heller.
+ * Copyright (C) 1999-2012. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
- * CYBOI is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * CYBOI is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
  * CYBOI is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * but WITHOUT ANY WARRANTY; without even the implied warranty
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with CYBOI.  If not, see <http://www.gnu.org/licenses/>.
+ * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
  *
- * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
+ * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: primitive_type_size.c,v $ $Revision: 1.2 $ $Date: 2009-01-31 16:06:34 $ $Author: christian $
+ * @version CYBOP 0.11.0 2012-01-01
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,10 +27,10 @@
 #define REAL_TYPE_SIZE_SOURCE
 
 //
-// CAUTION! Do NOT try to assign any values here!
-// Otherwise, the compiler shows the following error:
-// "error: initializer element is not constant"
-// Therefore, the variables are only initialised in module "globaliser.c".
+// The global variables.
+//
+// CAUTION! This is just the variable definition.
+// Initialisation happens in directory "controller/globaliser/".
 //
 
 //
@@ -81,7 +81,8 @@
  * Typical size [Byte]: 4
  * Typical size [Bit]: 32
  */
-static signed char* FLOAT_REAL_TYPE_SIZE;
+static int FLOAT_REAL_TYPE_SIZE_ARRAY[1];
+static int* FLOAT_REAL_TYPE_SIZE = FLOAT_REAL_TYPE_SIZE_ARRAY;
 
 /**
  * The double real type size.
@@ -93,7 +94,8 @@ static signed char* FLOAT_REAL_TYPE_SIZE;
  * Typical size [Byte]: 8
  * Typical size [Bit]: 64
  */
-static signed char* DOUBLE_REAL_TYPE_SIZE;
+static int DOUBLE_REAL_TYPE_SIZE_ARRAY[1];
+static int* DOUBLE_REAL_TYPE_SIZE = DOUBLE_REAL_TYPE_SIZE_ARRAY;
 
 /**
  * The long double real type size.
@@ -105,7 +107,8 @@ static signed char* DOUBLE_REAL_TYPE_SIZE;
  * Typical size [Byte]: 8 or 12
  * Typical size [Bit]: 64 or 96
  */
-static signed char* LONG_DOUBLE_REAL_TYPE_SIZE;
+static int LONG_DOUBLE_REAL_TYPE_SIZE_ARRAY[1];
+static int* LONG_DOUBLE_REAL_TYPE_SIZE = LONG_DOUBLE_REAL_TYPE_SIZE_ARRAY;
 
 /* REAL_TYPE_SIZE_SOURCE */
 #endif
